@@ -1,6 +1,7 @@
+pub use diagnostics_observer::DiagnosticsEvent;
 pub use sdk_errors_observer::ErrorBoundaryEvent;
 
+pub mod diagnostics_observer;
 pub mod observability_client_adapter;
 pub mod ops_stats;
 pub mod sdk_errors_observer;
-pub mod util;
